@@ -96,35 +96,36 @@ def is_distinct(coll):
     return len(coll) == len(set(coll))
 
 
-def all(pred, coll=None):
-    if coll is None:
+def all(pred, seq=None):
+    if seq is None:
         return _all(pred)
-    return _all(imap(pred, coll))
+    return _all(imap(pred, seq))
 
-def any(pred, coll=None):
-    if coll is None:
+def any(pred, seq=None):
+    if seq is None:
         return _any(pred)
-    return _any(imap(pred, coll))
+    return _any(imap(pred, seq))
 
 none = complement(any)
 
-def one(pred, coll=None):
-    if coll is None:
+def one(pred, seq=None):
+    if seq is None:
         return one(bool, pred)
-    return len(take(2, ifilter(pred, coll))) == 1
+    return len(take(2, ifilter(pred, seq))) == 1
 
 # Not same as in clojure! returns value found not pred(value)
 # NOTE: should I name it "find" when pred is here
-def some(pred, coll=None):
-    if coll is None:
+def some(pred, seq=None):
+    if seq is None:
         return some(None, pred)
-    return next(ifilter(pred, coll), None)
+    return next(ifilter(pred, seq), None)
 
 # TODO: a variant of some that returns mapped value,
 #       one can use some(imap(f, seq)) or first(ikeep(f, seq)) for now.
-#       Call it `find`?
 
 # TODO: vector comparison tests - ascending, descending and such
+# def chain_test(compare, seq):
+#     return all(compare, izip(seq, rest(seq))
 
 # TODO: capabilities + type tests or skip?
 
@@ -142,11 +143,8 @@ def where(mappings, **cond):
     match = lambda m: all(m[k] == v for k, v in cond.items())
     return filter(match, mappings)
 
-# NOTE: should I change params order to be more consistent with map/filter
-#       or leave as is to be consistent with where/invoke?
-def pluck(mappings, key):
+def pluck(key, mappings):
     return map(itemgetter(key), mappings)
 
-
 def invoke(objects, name, *args, **kwargs):
     return map(methodcaller(name, *args, **kwargs), objects)
